sentry-slack
============

An extension for `Sentry <https://getsentry.com>`_ which posts notifications to a `Slack <https://slack.com>`_ channel.

.. image:: http://i.imgur.com/MFsjVmB.png

Install
-------

Install the package via ``pip``::

    pip install sentry-slack

You can now configure webhooks via the plugin configuration panel within your project.
